function p = calc_triplet_prob(p3,pideal, R,n, MIN_PRECISION)
% CALC_TRIPLET_PROB computes formula for triplet probability
% if the length of the vector is L, then the number of points in the curve
% is L+2 (it is based on the triplet model)
%
% p = calc_triplet_prob(p3, pideal, R, n, MIN_PRECISION
% 
%  Input
%   - p3: location of the third point in a triplet 
%   - pideal: location of the ideal symmetric point in the triplet
%   - R: radius of the local window
%   - n: number of points in the local window
%   - MIN_PRECISION: minimum precision of the discrete domain (to avoid
%   computing the probability of the perfect triplet)
%  Output
%   - p: probability (error) of the triplet

% IPOL SUBMISSION "An Unsupervised Algorithm for Detecting Good 
% Continuation in Dot Patterns"
% 
% Version 0.4, April 2017
%
% Copyright (c) 2017 Jose Lezama <jlezama@fing.edu.uy>
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as
% published by the Free Software Foundation, either version 3 of the
% License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Affero General Public License for more details.
% 
% You should have received a copy of the GNU Affero General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.

r = pdist2p(p3,pideal);
r = max(r, MIN_PRECISION);

p = 1-(1-r^2/R^2)^n;

