function [NFA, max_p] = chain_nfa(chain, N, b)
% CHAIN_NFA calculates the NFA of a chain of triplets given as a vector of probabilities
% if the length of the vector is L, then the number of points in the curve
% is L+2 (it is based on the triplet model)
%
% [NFA, max_p] = chain_nfa(chain, N, b)
% 
%  Input
%   - chain: a vector of the probabilities of each triplet in a chain
%   - N: the total number of points in the figure
%   - b: the number of nearest neighbors to explore
%  Output
%   - NFA: NFA of the chain
%   - max_p: maximum probability in the chain

% IPOL SUBMISSION "An Unsupervised Algorithm for Detecting Good
% Continuation in Dot Patterns"
% 
% Version 0.4, April 2017
%
% Copyright (c) 2017 Jose Lezama <jlezama@fing.edu.uy>
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as
% published by the Free Software Foundation, either version 3 of the
% License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Affero General Public License for more details.
% 
% You should have received a copy of the GNU Affero General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.

max_p = max(chain);
L = length(chain);
K = L+2;

Ntests =  b * N * sqrt(N) ;

NFA = Ntests * max_p^(K-2);
