function NFAs = compute_paths_NFAs(PathDists, P, triplets, N, b)
% COMPUTE_PATHS_NFAS computes the NFAs for the paths (chains of triplets)
% returned by Floyd-Warshall
% 
% NFAs = compute_paths_NFAs(PathDists, P, triplets, N, b)
% 
%  Input
%   - PathDists: TxT matrix of distances for every path between triplets
%   - P: TxT matrix representing the paths
%   - triplets: Tx4 array of triplets ([i, j, k, p])
%   - N: number of points in the domain
%   - b: number of nearest neighbors to explore
%  Output
%   - NFAs: TxT matrix of NFAs for every path between triplets
%   - minNFA: minimum NFA

% IPOL SUBMISSION "An Unsupervised Algorithm for Detecting Good 
% Continuation in Dot Patterns"
% 
% Version 0.4, April 2017
%
% Copyright (c) 2017 Jose Lezama <jlezama@fing.edu.uy>
% 
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as
% published by the Free Software Foundation, either version 3 of the
% License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
% GNU Affero General Public License for more details.
% 
% You should have received a copy of the GNU Affero General Public License
% along with this program. If not, see <http://www.gnu.org/licenses/>.

T = size(triplets,1);
NFAs = ones(size(PathDists))*inf;

tstart = tic;
tic
disp('Analyzing paths found by Floyd-Warshal...')
for x = 1:T
    for y =1:T
        
        if PathDists(x,y)==inf
            continue
        end
        
        if toc > 3
            fprintf('Analyzing path from %i to %i (of %i)\n', x, y , T);
            tic
        end
        
        fw_path = get_fw_path(x,y,P);
        
        % calculate NFA
        probs = triplets(fw_path,4);
        NFAs(x,y) =  chain_nfa(probs, N, b);
    end
end
toc(tstart);
